@@ -1,4 +1,5 @@
 """Provide a two-way Pandas DataFrame interface to Eclipse summary data (UNSMRY)"""
+import os
 import logging
 from pathlib import Path
 
@@ -647,8 +648,15 @@ def fill_parser(parser):
 
 def fill_reverse_parser(parser):
     """Fill a parser for the operation:  dataframe -> eclsum files"""
+
+    parser.add_argument(
+        "-o",
+        "--output",
+        type=str,
+        help="Basename for Eclipse output files",
+        default="SYNTSMRY",
+    )
     parser.add_argument("csvfile", help="Name of CSV file with summary data.")
-    parser.add_argument("ECLBASE", help="Basename for Eclipse output files")
     parser.add_argument("-v", "--verbose", action="store_true", help="Be verbose")
     parser.add_argument("--debug", action="store_true", help="Be verbose")
     return parser
@@ -687,8 +695,14 @@ def summary_reverse_main(args):
     summary_df = pd.read_csv(args.csvfile)
     logger.info("Parsed %s", args.csvfile)
 
-    eclsum = df2eclsum(summary_df, args.ECLBASE)
+    outputdir = Path(args.output).parent
+    eclbase = Path(args.output).name
+
+    # EclSum.fwrite can only write to current directory:
+    cwd = os.getcwd()
+    os.chdir(outputdir)
+    eclsum = df2eclsum(summary_df, eclbase)
     EclSum.fwrite(eclsum)
-    logger.info(
-        "Wrote to %s and %s", args.ECLBASE + ".UNSMRY", args.ECLBASE + ".SMSPEC"
-    )
+    os.chdir(cwd)
+
+    logger.info("Wrote to %s and %s", args.output + ".UNSMRY", args.output + ".SMSPEC")
